csvupdate

package
v0.0.0-...-3eea053 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 29, 2024 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CSVFile

type CSVFile struct {
	Header   []string
	Headers  map[string]int
	Data     [][]string
	FileName string
}

func (*CSVFile) WriteCSV

func (c *CSVFile) WriteCSV() error

type UpdateTool

type UpdateTool struct {
	OutdatedCSV, UpdatedCSV *CSVFile
	CompareBy               string
	UpdateFields            []string
}

func NewUpdateTool

func NewUpdateTool(outdated, updated, compareby, fields string) (*UpdateTool, error)

NewUpdateTool takes both the outdated and updated csv, the relevant fields and returns an instance of UpdateTool with both CSVs parsed.

func (*UpdateTool) UpdateCSV

func (u *UpdateTool) UpdateCSV() error

Jump to