Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type UpdateTool ¶
func NewUpdateTool ¶
func NewUpdateTool(outdated, updated, compareby, fields string) (*UpdateTool, error)
NewUpdateTool takes both the outdated and updated csv, the relevant fields and returns an instance of UpdateTool with both CSVs parsed.
func (*UpdateTool) UpdateCSV ¶
func (u *UpdateTool) UpdateCSV() error
Click to show internal directories.
Click to hide internal directories.